%%%%% Used to analyze data for the stopsignal meta analysis
%%%%% This version looks at the entire run, rather than just the second
%%%%% half.
%%%%% Created by Eric Miller
%%%%% Modified by Eliza Congdon for CNP LA5C scan performance (12/2/09)
%%%%% Modified by Angelica to run on PILOT scans (09/22/10)

%Appends to the output file "stopsig_group_output.txt" the following values:
%1. Subject Name
%2. GRT Mean
%3. GRT Median
%4. GRT Quantile value
%5. GRT Standard Deviation
%6. Ladder1 Mean
%7. Ladder2 Mean
%8. SSDFifty
%9. Pct Dimension/Direction Errors
%10. SSRT (Quantile Estimate)
%11. Pct Inhib Ladder 1
%12. Pct Inhib Ladder 2
%13. Pct go trials answered

 directory_name = ['CONTROLS']
% directory_name = ['SCHZ']
% directory_name = ['BIPOLAR']
% directory_name = ['ADHD']
% directory_name = ['PILOTS']

%function make_stopsig_onsets_function(directory_name)
base_directory = sprintf('/space/raid2/data/poldrack/CNP/%s',directory_name);
cd(base_directory);
subs = dir('*B');


%This version is updated to adjust for differences in trigger time.  If
%trigger time is unknown (trigger_time does not exist), then no adjustments
%are made.

for g=1:length(subs)
cd(base_directory);
cd(subs(g).name);
cd behav;
cd STOPSIGNAL
LEFT = 5; 
RIGHT= 28; 
%RIGHT = 10;     % subj 60062 responses are 10 (R) and 28 (L)
%LEFT = 28;

% If you want to run the group, remove lines 51 and 163; change 'a' to 'w'
% in logfile. 
% IF you want to run the group, YOU ALSO MUST comment out all the Figure Codes.
% Eliza, 12/02/09
%%%%%%%%%%%%%%%%%
%%subset    
if subs(g).name == 'CNP_10882B'
%%%%%%%%%%%%%%%%%  

try

%%%% reads in mat file 
clear filename;
clear trigger_time;
filename=dir('*stop_fmri2*');
load(filename.name);
% for CNP_10501, CNP_10523, CNP_50014 = USE THIS ONE 
%load(filename(2).name);


late_amount = 0;
if exist('trigger_time')
    if trigger_time > 10 && trigger_time < 12 late_amount = 2; end
    if trigger_time > 12 && trigger_time < 14 late_amount = 4; end
    if trigger_time > 14 && trigger_time < 16 late_amount = 6; end
end

sprintf('Making STOPSIGNAL behav output for %s',subs(g).name)

%%%% Make SSD graphs
% 
% a = max(Ladder1);
% b = max(Ladder2);
% ymax=max([a b]);
% a = min(Ladder1);
% b = min(Ladder2);
% ymin=min([a b]);
% if ymin>0,
% 	ymin=0;
% end;
% 
% 
% xmax=length(Ladder1)+1;
% 
% for a=1:size(Ladder1),
% 	Ladder1Plot(2*a-1)=Ladder1(a);
% 	Ladder2Plot(2*a-1)=Ladder2(a);
% 	Ladder1Plot(2*a)=Ladder1(a);
% 	Ladder2Plot(2*a)=Ladder2(a);
% end;
% 
% 
% 
% subplot(2,2,1);
% for a=1:size(Ladder1)-1;
% 	hold on;
% 	plot(a:a+1,Ladder1Plot(2*a-1:2*a), 'b');
% 	plot([a+1 a+1],Ladder1Plot(2*a:2*a+1), 'b');
% end;
% axis([1 xmax ymin ymax]);
% subplot(2,2,2);
% for a=1:size(Ladder2)-1;
% 	hold on;
% 	plot(a:a+1,Ladder2Plot(2*a-1:2*a), 'b');
% 	plot([a+1 a+1],Ladder2Plot(2*a:2*a+1), 'b');
% end;
% axis([1 xmax ymin ymax]);


%%%% Actual Analysis...
GRTmedian=median(Seeker(find(Seeker(:,1)>0 & Seeker(:,3)==0 & ((Seeker(:,4)==0 & Seeker(:,7)==LEFT)|(Seeker(:,4)==1 & Seeker(:,7)==RIGHT))),9)*1000);
GRTmean=mean(Seeker(find(Seeker(:,1)>0 & Seeker(:,3)==0 & ((Seeker(:,4)==0 & Seeker(:,7)==LEFT)|(Seeker(:,4)==1 & Seeker(:,7)==RIGHT))),9)*1000);
GRTstd=std(Seeker(find(Seeker(:,1)>0 & Seeker(:,3)==0 & ((Seeker(:,4)==0 & Seeker(:,7)==LEFT)|(Seeker(:,4)==1 & Seeker(:,7)==RIGHT))),9)*1000);

Ladder1mean=mean(Ladder1);
Ladder2mean=mean(Ladder2);
  
DimErrors=sum((Seeker(:,3)==0 & ( (Seeker(:,4)==0 & Seeker(:,7)==RIGHT) | ( Seeker(:,4)==1 & Seeker(:,7)==LEFT ))));
PctDimErrors=100*sum((Seeker(:,3)==0 & ((Seeker(:,4)==0 & Seeker(:,7)==RIGHT) | (Seeker(:,4)==1 & Seeker(:,7)==LEFT))))/sum(Seeker(:,3)==0);
SSDfifty=mean([Ladder1mean Ladder2mean]);
SSRT=GRTmedian-SSDfifty;

for ladder=1:2,
    numberInhibs=length(find(Seeker(:,1)>0 & (Seeker(:,5)==ladder & Seeker(:,7)==0)));
    numberInhibTrials=length(find(Seeker(:,1)>0 & (Seeker(:,5)==ladder)));
    PctInhib(ladder)=100*numberInhibs/numberInhibTrials;
end;
averageLadderInhib=(mean(PctInhib)/100);

%Analysis to get SSRT using quantile based on actual PctInhib as opposed to assuming 50% like above
corr_rt=Seeker(find(Seeker(:,1)>0 & Seeker(:,3)==0 & ((Seeker(:,4)==0 & Seeker(:,7)==LEFT)|(Seeker(:,4)==1 & Seeker(:,7)==RIGHT))),9)*1000;
GRTquant=quantile(corr_rt,1-averageLadderInhib);
SSRTquant=GRTquant-SSDfifty;

PctGoResp=100*(sum(Seeker(:,3)==0 & Seeker(:,7) ~= 0) / sum(Seeker(:,3)==0));

%Check RT distribution in Figure
% subplot(2,1,2); 
% plot(corr_rt,'o')

%Print subject-specific performance output
fid=fopen(sprintf('%s_STOPSIGNAL_behav_output.txt',subs(g).name),'w');
fprintf(fid,'GRTmean\tGRTmedian\tGRTquant\tGRTstd\tLadder1mean\tLadder2mean\tSSDfifty\tPctDimErrors\tSSRTquant\tPctInhibL1\tPctInhibL2\tPctGoResp\n');
fprintf(fid,'%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t',GRTmean, GRTmedian, GRTquant, GRTstd, Ladder1mean, Ladder2mean, SSDfifty, PctDimErrors, SSRTquant, PctInhib, PctGoResp);
fprintf(fid,'\n');
fclose(fid);

%Print subject performance output to the group output file: 
fid=fopen(sprintf('/space/raid2/data/poldrack/CNP/scripts/behav_analyze/STOPSIGNAL/%s_stopsig_group_output.txt', directory_name), 'a');
fprintf(fid,'%s\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t%0.3f\t', subs(g).name, GRTmean, GRTmedian, GRTquant, GRTstd, Ladder1mean, Ladder2mean, SSDfifty, PctDimErrors, SSRTquant, PctInhib, PctGoResp);
fprintf(fid,'\n');
fclose(fid);


catch
    fprintf('%s didnt work or doesnt exist!\n',subs(g).name);
end;
    
    
%%%%%%%%%%%%%%%%%%%%%%%
end; %for single-subject analysis
%%%%%%%%%%%%%%%%%%%%%%%    
    

    cd /space/raid2/data/poldrack/CNP/scripts/behav_analyze/STOPSIGNAL;
    
end;